﻿Type=Class
Version=3.96
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	Private ws As WebSocket 'ignore
	' will hold our page information
	Public page As ABMPage
	' page theme
	Private theme As ABMTheme
	' to access the constants
	Private ABM As ABMaterial 'ignore	
	' name of the page, must be the same as the class name (case sensitive!)
	Public Name As String = "HelperContainerPage"
	' name of the app, same as in ABMApplication
	Public AppName As String = "demo"
	
	' your own variables
	Dim myToastId As Int
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize
	' build the local structure IMPORTANT!
	BuildPage
End Sub

Private Sub WebSocket_Connected (WebSocket1 As WebSocket)
	Log("Connected")
	ws = WebSocket1	
	If ABMShared.NeedsAuthorization Then
		If ws.Session.GetAttribute2("IsAuthorized", "") = "" Then
			ABMShared.NavigateToPage(ws, "../")
			Return
		End If
	End If
	' connect our page with the websocket	
	page.SetWebSocket(ws)
	' Prepare the page IMPORTANT!
	page.Prepare	
End Sub

Private Sub WebSocket_Disconnected
	Log("Disconnected")
End Sub

Sub Page_ParseEvent(Params As Map) 
	Dim eventName As String = Params.Get("eventname")
	Dim eventParams() As String = Regex.Split(",",Params.Get("eventparams"))
	If SubExists(Me, eventName) Then
		Params.Remove("eventname")
		Params.Remove("eventparams")
		Select Case Params.Size
			Case 0
				CallSub(Me, eventName)
			Case 1
				CallSub2(Me, eventName, Params.Get(eventParams(0)))					
			Case 2
				If Params.get(eventParams(0)) = "abmistable" Then
					Dim PassedTables As List = ABM.ProcessTablesFromTargetName(Params.get(eventParams(1)))
					CallSub2(Me, eventName, PassedTables)
				Else
					CallSub3(Me, eventName, Params.Get(eventParams(0)), Params.Get(eventParams(1)))
				End If
			Case Else
				' cannot be called diretly, to many param
				CallSub2(Me, eventName, Params)				
		End Select
	End If
End Sub

public Sub BuildTheme()
	' start with the base theme defined in ABMShared
	theme.Initialize("pagetheme")
	theme.AddABMTheme(ABMShared.MyTheme)
	
	' add additional themes specific for this page
	' cell theme
	theme.AddCellTheme("cellLB")
	theme.Cell("cellLB").BackColor = ABM.COLOR_LIGHTBLUE
	theme.Cell("cellLB").BorderColor = ABM.COLOR_WHITE
	theme.Cell("cellLB").BorderWidth = 1
	
	' grid label
	theme.AddLabelTheme("lblGrid")
	theme.Label("lblGrid").ForeColor = ABM.COLOR_WHITE
	theme.Label("lblGrid").Align = ABM.TEXTALIGN_CENTER
End Sub

public Sub BuildPage()
	' initialize the theme
	BuildTheme
	
	' initialize this page using our theme
	page.InitializeWithTheme(Name, "/ws/" & AppName & "/" & Name, False, theme)
	page.ShowLoader=True
	page.PageTitle = "ABMContainer"
	page.PageDescription = "The container helper"	
	page.PageHTMLName = "abmaterial-container.html"
	page.PageKeywords = "ABMaterial, material design, B4X, B4J, SEO, framework, search engine optimization"
	page.PageSiteMapPriority = "0.50"
	page.PageSiteMapFrequency = ABM.SITEMAP_FREQ_MONTHLY
	'page.ShowGridInfo = True
	
		
	ABMShared.BuildNavigationBar(page, "ABMContainer", "../images/logo.png", "", "Helpers", "ABMContainer")
		
	' create the page grid
	page.AddRows(1,True, "").AddCells12(1,"")
	page.AddRows(1,True,"").AddCellsOS(2,0,0,0,6,6,6,"")
	page.AddRows(4,True, "").AddCells12(1,"")
	page.BuildGrid 'IMPORTANT once you loaded the complete grid AND before you start adding components
	
	' add paragraph
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par1","The best way to look at a ABMContainer component is like it is a mini ABMPage helper.  It has less options but the flow is almost the same.  You can add Rows, Cells and other components.") )
	' add paragraph
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par2","ABMContainers are mosly used to further drill down a cell defined in the page.  With an ABMContainer control, you get again a grid of 12 cells so you can do exactly as it was a page.") )
	' add paragraph
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par3","Lets show an example.  We have a page with a row split into two columns of each 6 cells.  In the left cell we've added a container with the grid example from the ABMPage chapter.") )
	
	' create the container
	Dim cont1 As ABMContainer
	cont1.Initialize(page, "cont1", "")
	cont1.AddRows(1,True, "").AddCells12(1,"")	
	cont1.AddRowsM(1,True,0,0, "").AddCellsOS(12,0,0,0,1,1,1,"")
	cont1.AddRows(1,True, "").AddCells12(1,"")	
	cont1.BuildGrid ' IMPORTANT
	
	' add sub header
	cont1.Cell(1,1).AddComponent(ABMShared.BuildSubHeader(page, "shdr1", "12 Cells"))
	' add paragraph
	cont1.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page, "par2","Our standard grid has 12 cells. No matter the size of the browser, each of these cells will always have an equal width."))
	' add 12 cells
	For i=1 To 12
		cont1.Cell(2,i).UseTheme("cellLB")
		Dim lblGrid As ABMLabel
		lblGrid.Initialize(page, "Rgrid2C" & i & "Label", "" & i, ABM.SIZE_H6, True, "lblGrid")
		cont1.Cell(2,i).AddComponent(lblGrid)
	Next
	
	' add paragraph
	cont1.Cell(3,1).AddComponent(ABMShared.BuildParagraph(page, "par3", "To get a feel of how the grid is used ..."))
	
	page.Cell(2,1).AddComponent(cont1)
	
	Dim code As String = $"// create the container
Dim cont1 As ABMContainer
cont1.Initialize(page, "cont1", "")
cont1.AddRows(1,True, "").AddCells12(1,"")	
cont1.AddRowsM(1,True,0,0, "").AddCellsOS(12,0,0,0,1,1,1,"")
cont1.AddRows(1,True, "").AddCells12(1,"")	
cont1.BuildGrid // IMPORTANT
	
// add sub header
cont1.Cell(1,1).AddComponent(ABMShared.BuildSubHeader(page, "shdr1", "12 Cells"))
// add paragraph
cont1.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page, "par2","Our standard grid has 12 cells. No matter the size of the browser, each of these cells will always have an equal width."))
// add 12 cells
For i=1 To 12
	cont1.Cell(2,i).UseTheme("cellLB")
	Dim lblGrid As ABMLabel
	lblGrid.Initialize(page, "Rgrid2C" & i & "Label", "" & i, ABM.SIZE_H6, True, "lblGrid")
	cont1.Cell(2,i).AddComponent(lblGrid)
Next
	
// add paragraph
cont1.Cell(3,1).AddComponent(ABMShared.BuildParagraph(page, "par3", "To get a feel of how the grid is used ..."))
	
page.Cell(2,1).AddComponent(cont1)"$
	
	page.Cell(2,2).AddComponent(ABMShared.BuildCodeBlockFromSmartString(page, "code1", code))
	
	' add paragraph
	page.Cell(3,1).AddComponent(ABMShared.BuildParagraph(page,"par4","As you can see, this code is almost exactly the same as the beginning of the code in the ABMPage chapter, except we changed page.Add... to cont1.Add... and added the components accordingly."))
	
	' add paragraph
	page.Cell(3,1).AddComponent(ABMShared.BuildParagraph(page,"par5","This is a very powerful component and if you take your time to think about how the grid of your page must look like, a real time saver."))
	
	' add paragraph
	page.Cell(3,1).AddComponent(ABMShared.BuildParagraph(page,"par6","For further information on how the container works, check out the ABMPage and the Grids chapter (but I'm sure you know that one by heart by now)."))
	
	ABMShared.BuildFooter(page)
End Sub

' clicked on the navigation bar
Sub Page_NavigationbarClicked(Action As String, Value As String)
	page.SaveNavigationBarPosition	
	If Action = "ABMContainer" Then Return
	If Action = "Contact" Then	
		myToastId = myToastId + 1	
		page.ShowToast("toast" & myToastId, "toastred", "Hello to you too!", 5000)
		Return
	End If
	If Action = "LogOff" Then
		ABMShared.LogOff(page)
		Return
	End If
	ABMShared.NavigateToPage(ws, Value)
End Sub

Sub Page_SignedOffSocialNetwork(Network As String, Extra As String)
	page.ws.Session.SetAttribute("authType", "")
	page.ws.Session.SetAttribute("authName", "")
	page.ws.Session.SetAttribute("IsAuthorized", "")			
	ABMShared.NavigateToPage(page.ws, "../")
End Sub

Sub Page_Ready()
	Log("ready!")
	page.RestoreNavigationBarPosition
End Sub